@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 
 
 require_once dirname(__FILE__).'/graphs.inc.php';
-require_once dirname(__FILE__).'/screens.inc.php';
 require_once dirname(__FILE__).'/maps.inc.php';
 require_once dirname(__FILE__).'/users.inc.php';
 
@@ -49,6 +48,7 @@ function getSystemStatusData(array $filter) {
 		: EXTACK_OPTION_ALL;
 	$filter_evaltype = array_key_exists('evaltype', $filter) ? $filter['evaltype'] : TAG_EVAL_TYPE_AND_OR;
 	$filter_tags = array_key_exists('tags', $filter) ? $filter['tags'] : [];
+	$show_opdata = array_key_exists('show_opdata', $filter) && $filter['show_opdata'] != OPERATIONAL_DATA_SHOW_NONE;
 
 	if (array_key_exists('exclude_groupids', $filter) && $filter['exclude_groupids']) {
 		if ($filter_hostids === null) {
@@ -93,10 +93,10 @@ function getSystemStatusData(array $filter) {
 		'stats' => [],
 		'allowed' => [
 			'ui_problems' => CWebUser::checkAccess(CRoleHelper::UI_MONITORING_PROBLEMS),
-			'ack' => CWebUser::checkAccess(CRoleHelper::ACTIONS_ACKNOWLEDGE_PROBLEMS)
-					|| CWebUser::checkAccess(CRoleHelper::ACTIONS_CLOSE_PROBLEMS)
-					|| CWebUser::checkAccess(CRoleHelper::ACTIONS_CHANGE_SEVERITY)
-					|| CWebUser::checkAccess(CRoleHelper::ACTIONS_ADD_PROBLEM_COMMENTS)
+			'add_comments' => CWebUser::checkAccess(CRoleHelper::ACTIONS_ADD_PROBLEM_COMMENTS),
+			'change_severity' => CWebUser::checkAccess(CRoleHelper::ACTIONS_CHANGE_SEVERITY),
+			'acknowledge' => CWebUser::checkAccess(CRoleHelper::ACTIONS_ACKNOWLEDGE_PROBLEMS),
+			'close' => CWebUser::checkAccess(CRoleHelper::ACTIONS_CLOSE_PROBLEMS)
 		]
 	];
 
@@ -119,7 +119,8 @@ function getSystemStatusData(array $filter) {
 	unset($group);
 
 	$options = [
-		'output' => ['eventid', 'objectid', 'clock', 'ns', 'name', 'acknowledged', 'severity'],
+		'output' => ['eventid', 'r_eventid', 'objectid', 'clock', 'ns', 'name', 'acknowledged', 'severity'],
+		'selectAcknowledges' => ['action'],
 		'groupids' => array_keys($data['groups']),
 		'hostids' => $filter_hostids,
 		'evaltype' => $filter_evaltype,
@@ -163,25 +164,41 @@ function getSystemStatusData(array $filter) {
 		}
 
 		$options = [
-			'output' => ['priority'],
+			'output' => ['priority', 'manual_close'],
 			'selectGroups' => ['groupid'],
 			'selectHosts' => ['name'],
-			'selectItems' => ['itemid', 'hostid', 'name', 'key_', 'value_type', 'units', 'valuemapid'],
 			'triggerids' => array_keys($triggerids),
 			'monitored' => true,
 			'skipDependent' => true,
 			'preservekeys' => true
 		];
 
-		if (array_key_exists('show_opdata', $filter) && $filter['show_opdata'] != OPERATIONAL_DATA_SHOW_NONE) {
-			$options['output'] = array_merge(
-				$options['output'],
-				['url', 'expression', 'recovery_mode', 'recovery_expression', 'opdata']
+		if ($show_opdata) {
+			$options['selectFunctions'] = ['itemid'];
+			$options['output'] = array_merge($options['output'],
+				['expression', 'recovery_mode', 'recovery_expression', 'opdata']
 			);
 		}
 
 		$data['triggers'] = API::Trigger()->get($options);
 
+		if ($show_opdata && $data['triggers']) {
+			$items = API::Item()->get([
+				'output' => ['itemid', 'hostid', 'name', 'key_', 'value_type', 'units'],
+				'selectValueMap' => ['mappings'],
+				'triggerids' => array_keys($data['triggers']),
+				'preservekeys' => true
+			]);
+
+			foreach ($data['triggers'] as &$trigger) {
+				foreach ($trigger['functions'] as $function) {
+					$trigger['items'][] = $items[$function['itemid']];
+				}
+				unset($trigger['functions']);
+			}
+			unset($trigger);
+		}
+
 		foreach ($data['triggers'] as &$trigger) {
 			CArrayHelper::sort($trigger['hosts'], [['field' => 'name', 'order' => ZBX_SORT_UP]]);
 		}
@@ -275,7 +292,7 @@ function getSystemStatusData(array $filter) {
 		$data['actions'] = [
 			'all_actions' => $actions['data'],
 			'users' => API::User()->get([
-				'output' => ['alias', 'name', 'surname'],
+				'output' => ['username', 'name', 'surname'],
 				'userids' => array_keys($actions['userids']),
 				'preservekeys' => true
 			]),
@@ -298,148 +315,6 @@ function getSystemStatusData(array $filter) {
 	return $data;
 }
 
-/**
- * @param array  $filter
- * @param array  $filter['hostids']            (optional)
- * @param string $filter['problem']            (optional)
- * @param array  $filter['severities']         (optional)
- * @param int    $filter['show_suppressed']    (optional)
- * @param int    $filter['hide_empty_groups']  (optional)
- * @param int    $filter['ext_ack']            (optional)
- * @param int    $filter['show_timeline']      (optional)
- * @param int    $filter['show_opdata']        (optional)
- * @param array  $data
- * @param array  $data['groups']
- * @param string $data['groups'][]['groupid']
- * @param string $data['groups'][]['name']
- * @param bool   $data['groups'][]['has_problems']
- * @param array  $data['groups'][]['stats']
- * @param int    $data['groups'][]['stats']['count']
- * @param array  $data['groups'][]['stats']['problems']
- * @param string $data['groups'][]['stats']['problems'][]['eventid']
- * @param string $data['groups'][]['stats']['problems'][]['objectid']
- * @param int    $data['groups'][]['stats']['problems'][]['clock']
- * @param int    $data['groups'][]['stats']['problems'][]['ns']
- * @param int    $data['groups'][]['stats']['problems'][]['acknowledged']
- * @param array  $data['groups'][]['stats']['problems'][]['tags']
- * @param string $data['groups'][]['stats']['problems'][]['tags'][]['tag']
- * @param string $data['groups'][]['stats']['problems'][]['tags'][]['value']
- * @param int    $data['groups'][]['stats']['count_unack']
- * @param array  $data['groups'][]['stats']['problems_unack']
- * @param array  $data['triggers']
- * @param string $data['triggers'][<triggerid>]['expression']
- * @param string $data['triggers'][<triggerid>]['description']
- * @param array  $data['triggers'][<triggerid>]['hosts']
- * @param string $data['triggers'][<triggerid>]['hosts'][]['name']
- * @param array  $data['triggers'][<triggerid>]['opdata']
- * @param array  $data['allowed']
- * @param bool   $data['allowed']['ui_problems']
- * @param bool   $data['allowed']['ack']
- *
- * @return CDiv
- */
-function makeSystemStatus(array $filter, array $data) {
-	$filter_severities = (array_key_exists('severities', $filter) && $filter['severities'])
-		? $filter['severities']
-		: range(TRIGGER_SEVERITY_NOT_CLASSIFIED, TRIGGER_SEVERITY_COUNT - 1);
-	$filter_hide_empty_groups = array_key_exists('hide_empty_groups', $filter) ? $filter['hide_empty_groups'] : 0;
-	$filter_ext_ack = array_key_exists('ext_ack', $filter)
-		? $filter['ext_ack']
-		: EXTACK_OPTION_ALL;
-
-	// indicator of sort field
-	$sort_div = (new CSpan())->addClass(ZBX_STYLE_ARROW_UP);
-
-	// Set trigger severities as table header starting from highest severity.
-	$header = [[_('Host group'), $sort_div]];
-
-	for ($severity = TRIGGER_SEVERITY_COUNT - 1; $severity >= TRIGGER_SEVERITY_NOT_CLASSIFIED; $severity--) {
-		if (in_array($severity, $filter_severities)) {
-			$header[] = getSeverityName($severity);
-		}
-	}
-
-	$table = (new CTableInfo())
-		->setHeader($header)
-		->setHeadingColumn(0);
-
-	$url_group = $data['allowed']['ui_problems']
-		? (new CUrl('zabbix.php'))
-			->setArgument('action', 'problem.view')
-			->setArgument('filter_name', '')
-			->setArgument('show', TRIGGERS_OPTION_RECENT_PROBLEM)
-			->setArgument('hostids', array_key_exists('hostids', $filter) ? $filter['hostids'] : [])
-			->setArgument('name', array_key_exists('problem', $filter) ? $filter['problem'] : null)
-			->setArgument('show_suppressed',
-				(array_key_exists('show_suppressed', $filter) && $filter['show_suppressed'] == 1)
-					? 1
-					: null
-			)
-		: null;
-
-	foreach ($data['groups'] as $group) {
-		if ($filter_hide_empty_groups && !$group['has_problems']) {
-			continue;
-		}
-
-		if ($data['allowed']['ui_problems']) {
-			$url_group->setArgument('groupids', [$group['groupid']]);
-			$row = [new CLink($group['name'], $url_group->getUrl())];
-		}
-		else {
-			$row = [$group['name']];
-		}
-
-		foreach ($group['stats'] as $severity => $stat) {
-			if ($stat['count'] == 0 && $stat['count_unack'] == 0) {
-				$row[] = '';
-				continue;
-			}
-
-			$allTriggersNum = $stat['count'];
-			if ($allTriggersNum) {
-				$allTriggersNum = (new CLinkAction($allTriggersNum))
-					->setHint(makeProblemsPopup($stat['problems'], $data['triggers'], $data['actions'], $filter,
-						$data['allowed']
-					));
-			}
-
-			$unackTriggersNum = $stat['count_unack'];
-			if ($unackTriggersNum) {
-				$unackTriggersNum = (new CLinkAction($unackTriggersNum))
-					->setHint(makeProblemsPopup($stat['problems_unack'], $data['triggers'], $data['actions'], $filter,
-						$data['allowed']
-					));
-			}
-
-			switch ($filter_ext_ack) {
-				case EXTACK_OPTION_ALL:
-					$row[] = getSeverityCell($severity, $allTriggersNum);
-					break;
-
-				case EXTACK_OPTION_UNACK:
-					$row[] = getSeverityCell($severity, $unackTriggersNum);
-					break;
-
-				case EXTACK_OPTION_BOTH:
-					if ($stat['count_unack'] != 0) {
-						$row[] = getSeverityCell($severity, [
-							$unackTriggersNum, ' '._('of').' ', $allTriggersNum
-						]);
-					}
-					else {
-						$row[] = getSeverityCell($severity, $allTriggersNum);
-					}
-					break;
-			}
-		}
-
-		$table->addRow($row);
-	}
-
-	return $table;
-}
-
 /**
  * @param array  $data
  * @param array  $data['groups']
@@ -486,17 +361,20 @@ function getSystemStatusTotals(array $data) {
 }
 
 /**
- * @param array  $data
- * @param array  $data['data']
- * @param array  $data['data']['groups']
- * @param array  $data['data']['groups'][]['stats']
- * @param array  $data['filter']
- * @param array  $data['filter']['severities']
- * @param array  $data['allowed']
- * @param bool   $data['allowed']['ui_problems']
- * @param bool   $data['allowed']['ack']
- * @param bool   $hide_empty_groups
- * @param CUrl   $groupurl
+ * @param array $data
+ * @param array $data['data']
+ * @param array $data['data']['groups']
+ * @param array $data['data']['groups'][]['stats']
+ * @param array $data['filter']
+ * @param array $data['filter']['severities']
+ * @param array $data['allowed']
+ * @param bool  $data['allowed']['ui_problems']
+ * @param bool  $data['allowed']['add_comments']
+ * @param bool  $data['allowed']['change_severity']
+ * @param bool  $data['allowed']['acknowledge']
+ * @param bool  $data['allowed']['close']
+ * @param bool  $hide_empty_groups
+ * @param CUrl  $groupurl
  *
  * @return CTableInfo
  */
@@ -533,14 +411,18 @@ function makeSeverityTable(array $data, $hide_empty_groups = false, CUrl $groupu
 }
 
 /**
- * @param array  $data
- * @param array  $data['data']
- * @param array  $data['data']['groups']
- * @param array  $data['data']['groups'][]['stats']
- * @param array  $data['filter']
- * @param array  $data['filter']['severities']
- * @param array  $data['allowed']
- * @param bool   $data['allowed']['ack']
+ * @param array $data
+ * @param array $data['data']
+ * @param array $data['data']['groups']
+ * @param array $data['data']['groups'][]['stats']
+ * @param array $data['filter']
+ * @param array $data['filter']['severities']
+ * @param array $data['allowed']
+ * @param bool  $data['allowed']['ui_problems']
+ * @param bool  $data['allowed']['add_comments']
+ * @param bool  $data['allowed']['change_severity']
+ * @param bool  $data['allowed']['acknowledge']
+ * @param bool  $data['allowed']['close']
  *
  * @return CDiv
  */
@@ -561,22 +443,26 @@ function makeSeverityTotals(array $data) {
 }
 
 /**
- * @param int     $severity
- * @param array   $data
- * @param array   $data['data']
- * @param array   $data['data']['triggers']
- * @param array   $data['data']['actions']
- * @param array   $data['filter']
- * @param array   $data['filter']['ext_ack']
- * @param array   $data['severity_names']
- * @param array   $data['allowed']
- * @param bool    $data['allowed']['ack']
- * @param array   $stat
- * @param int     $stats['count']
- * @param array   $stats['problems']
- * @param int     $stats['count_unack']
- * @param array   $stats['problems_unack']
- * @param boolean $is_total
+ * @param int   $severity
+ * @param array $data
+ * @param array $data['data']
+ * @param array $data['data']['triggers']
+ * @param array $data['data']['actions']
+ * @param array $data['filter']
+ * @param array $data['filter']['ext_ack']
+ * @param array $data['severity_names']
+ * @param array $data['allowed']
+ * @param bool  $data['allowed']['ui_problems']
+ * @param bool  $data['allowed']['add_comments']
+ * @param bool  $data['allowed']['change_severity']
+ * @param bool  $data['allowed']['acknowledge']
+ * @param bool  $data['allowed']['close']
+ * @param array $stat
+ * @param int   $stat['count']
+ * @param array $stat['problems']
+ * @param int   $stat['count_unack']
+ * @param array $stat['problems_unack']
+ * @param bool  $is_total
  *
  * @return CCol|string
  */
@@ -736,13 +622,14 @@ function make_status_of_zbx() {
 /**
  * Generate table for dashboard triggers popup.
  *
- * @see makeSystemStatus
- *
  * @param array  $problems
  * @param string $problems[]['objectid']
  * @param int    $problems[]['clock']
  * @param int    $problems[]['ns']
- * @param array  $problems[]['acknowledged']
+ * @param string $problems[]['r_eventid']
+ * @param string $problems[]['acknowledged']
+ * @param array  $problems[]['acknowledges']
+ * @param string $problems[]['acknowledges'][]['action']
  * @param array  $problems[]['severity']
  * @param array  $problems[]['suppression_data']
  * @param array  $problems[]['tags']
@@ -751,6 +638,7 @@ function make_status_of_zbx() {
  * @param array  $triggers
  * @param string $triggers[<triggerid>]['expression']
  * @param string $triggers[<triggerid>]['description']
+ * @param string $triggers[<triggerid>]['manual_close']
  * @param array  $triggers[<triggerid>]['hosts']
  * @param string $triggers[<triggerid>]['hosts'][]['name']
  * @param string $triggers[<triggerid>]['opdata']
@@ -761,7 +649,10 @@ function make_status_of_zbx() {
  * @param array  $filter['show_opdata']      (optional)
  * @param array  $allowed
  * @param bool   $allowed['ui_problems']
- * @param bool   $allowed['ack']
+ * @param bool   $allowed['add_comments']
+ * @param bool   $allowed['change_severity']
+ * @param bool   $allowed['acknowledge']
+ * @param bool   $allowed['close']
  *
  * @return CTableInfo
  */
@@ -899,9 +790,24 @@ function makeProblemsPopup(array $problems, array $triggers, array $actions, arr
 			}
 		}
 
+		$can_be_closed = ($trigger['manual_close'] == ZBX_TRIGGER_MANUAL_CLOSE_ALLOWED && $allowed['close']);
+
+		if ($problem['r_eventid'] != 0) {
+			$can_be_closed = false;
+		}
+		else {
+			foreach ($problem['acknowledges'] as $acknowledge) {
+				if (($acknowledge['action'] & ZBX_PROBLEM_UPDATE_CLOSE) == ZBX_PROBLEM_UPDATE_CLOSE) {
+					$can_be_closed = false;
+					break;
+				}
+			}
+		}
+
 		// Create acknowledge link.
 		$is_acknowledged = ($problem['acknowledged'] == EVENT_ACKNOWLEDGED);
-		$problem_update_link = $allowed['ack']
+		$problem_update_link = ($allowed['add_comments'] || $allowed['change_severity'] || $allowed['acknowledge']
+				|| $can_be_closed)
 			? (new CLink($is_acknowledged ? _('Yes') : _('No')))
 				->addClass($is_acknowledged ? ZBX_STYLE_GREEN : ZBX_STYLE_RED)
 				->addClass(ZBX_STYLE_LINK_ALT)
