@@ -90,11 +90,11 @@ class CTemplate extends CHostGeneral {
 			'selectDiscoveries'			=> null,
 			'selectTriggers'			=> null,
 			'selectGraphs'				=> null,
-			'selectApplications'		=> null,
 			'selectMacros'				=> null,
 			'selectDashboards'			=> null,
 			'selectHttpTests'			=> null,
 			'selectTags'				=> null,
+			'selectValueMaps'			=> null,
 			'countOutput'				=> false,
 			'groupCount'				=> false,
 			'preservekeys'				=> false,
@@ -104,6 +104,7 @@ class CTemplate extends CHostGeneral {
 			'limitSelects'				=> null
 		];
 		$options = zbx_array_merge($defOptions, $options);
+		$this->validateGet($options);
 
 		// editable + PERMISSION CHECK
 		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
@@ -298,6 +299,24 @@ class CTemplate extends CHostGeneral {
 		return $result;
 	}
 
+	/**
+	 * Validates the input parameters for the get() method.
+	 *
+	 * @param array $options
+	 *
+	 * @throws APIException if the input is invalid
+	 */
+	protected function validateGet(array $options) {
+		// Validate input parameters.
+		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
+			'selectValueMaps' =>			['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => 'valuemapid,name,mappings,uuid']
+		]];
+		$options_filter = array_intersect_key($options, $api_input_rules['fields']);
+		if (!CApiInputValidator::validate($api_input_rules, $options_filter, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+		}
+	}
+
 	/**
 	 * Add template.
 	 *
@@ -318,8 +337,8 @@ class CTemplate extends CHostGeneral {
 				$template['name'] = $template['host'];
 			}
 
-			$ins_templates[] = array_intersect_key($template, array_flip(['host', 'name', 'description'])) +
-				['status' => HOST_STATUS_TEMPLATE];
+			$ins_templates[] = array_intersect_key($template, array_flip(['uuid', 'host', 'name', 'description']))
+				+ ['status' => HOST_STATUS_TEMPLATE];
 		}
 		unset($template);
 
@@ -410,7 +429,7 @@ class CTemplate extends CHostGeneral {
 	 *
 	 * @throws APIException if the input is invalid.
 	 */
-	protected function validateCreate(array $templates) {
+	protected function validateCreate(array &$templates) {
 		$groupIds = [];
 
 		foreach ($templates as &$template) {
@@ -530,6 +549,36 @@ class CTemplate extends CHostGeneral {
 				$this->validateTags($template);
 			}
 		}
+
+		$this->checkAndAddUuid($templates);
+	}
+
+	/**
+	 * Check that no duplicate UUID is being added. Add UUID to all templates, if it doesn't exist.
+	 *
+	 * @param array $templates_to_create
+	 *
+	 * @throws APIException
+	 */
+	protected function checkAndAddUuid(array &$templates_to_create): void {
+		foreach ($templates_to_create as &$template) {
+			if (!array_key_exists('uuid', $template)) {
+				$template['uuid'] = generateUuidV4();
+			}
+		}
+		unset($template);
+
+		$db_uuid = DB::select('hosts', [
+			'output' => ['uuid'],
+			'filter' => ['uuid' => array_column($templates_to_create, 'uuid')],
+			'limit' => 1
+		]);
+
+		if ($db_uuid) {
+			self::exception(ZBX_API_ERROR_PARAMETERS,
+				_s('Entry with UUID "%1$s" already exists.', $db_uuid[0]['uuid'])
+			);
+		}
 	}
 
 	/**
@@ -596,11 +645,17 @@ class CTemplate extends CHostGeneral {
 			'preservekeys' => true
 		]);
 
-		foreach ($templates as $template) {
+		foreach ($templates as $index => $template) {
 			if (!isset($dbTemplates[$template['templateid']])) {
 				self::exception(ZBX_API_ERROR_PERMISSIONS, _('You do not have permission to perform this operation.'));
 			}
 
+			if (array_key_exists('uuid', $template)) {
+				self::exception(ZBX_API_ERROR_PARAMETERS,
+					_s('Invalid parameter "%1$s": %2$s.', '/' . ($index + 1), _s('unexpected parameter "%1$s"', 'uuid'))
+				);
+			}
+
 			// Property 'auto_compress' is not supported for templates.
 			if (array_key_exists('auto_compress', $template)) {
 				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect input parameters.'));
@@ -741,17 +796,6 @@ class CTemplate extends CHostGeneral {
 			API::HttpTest()->delete(array_keys($delHttpTests), true);
 		}
 
-		// Applications
-		$delApplications = API::Application()->get([
-			'templateids' => $templateids,
-			'output' => ['applicationid'],
-			'nopermissions' => 1,
-			'preservekeys' => true
-		]);
-		if (!empty($delApplications)) {
-			API::Application()->delete(array_keys($delApplications), true);
-		}
-
 		// Get host prototype operations from LLD overrides where this template is linked.
 		$lld_override_operationids = [];
 
