@@ -31,8 +31,12 @@ if (!empty($data['hostid'])) {
 	$widget->setNavigation(getHostNavigation('items', $data['hostid']));
 }
 
+$url = (new CUrl('items.php'))
+	->setArgument('context', $data['context'])
+	->getUrl();
+
 // Create form.
-$form = (new CForm())
+$form = (new CForm('post', $url))
 	->setId('item-form')
 	->setName('itemForm')
 	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
@@ -64,6 +68,7 @@ if ($discovered_item) {
 			->setArgument('form', 'update')
 			->setArgument('parent_discoveryid', $data['item']['discoveryRule']['itemid'])
 			->setArgument('itemid', $data['item']['itemDiscovery']['parent_itemid'])
+			->setArgument('context', 'host')
 	));
 }
 
@@ -521,12 +526,7 @@ if ($data['display_interfaces']) {
 
 			$form->addVar('selectedInterfaceId', $data['interfaceid']);
 			$form_list->addRow((new CLabel(_('Host interface'), 'interface'))->setAsteriskMark(),
-				(new CTextBox('interface',
-					$interface['useip']
-						? $interface['ip'].' : '.$interface['port']
-						: $interface['dns'].' : '.$interface['port'],
-					true
-				))->setAriaRequired(),
+				(new CTextBox('interface', getHostInterface($interface), true))->setAriaRequired(),
 				'interface_row'
 			);
 		}
@@ -811,41 +811,32 @@ $form_list
 		'row_logtimefmt'
 	);
 
-if ($readonly) {
-	if ($data['valuemaps']) {
-		$valuemaps = [['valuemapid' => $data['valuemapid'], 'name' => $data['valuemaps']]];
-	}
-	else {
-		$valuemaps = [['valuemapid' => $data['valuemapid'], 'name' => _('As is')]];
-	}
-}
-else {
-	$valuemaps = $data['valuemaps'];
-	array_unshift($valuemaps, ['valuemapid' => 0, 'name' => _('As is')]);
-}
-
-$valuemap_select = (new CSelect('valuemapid'))
-	->setId('valuemapid')
-	->setValue($data['valuemapid'])
-	->setFocusableElementId('label-valuemap')
-	->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-	->setReadonly($readonly);
-
-foreach ($valuemaps as $valuemap) {
-	$valuemap_select->addOption(new CSelectOption($valuemap['valuemapid'], $valuemap['name']));
-}
-
-if (CWebUser::getType() == USER_TYPE_SUPER_ADMIN) {
-	$valuemap_select = [$valuemap_select, '&nbsp;',
-		(new CLink(_('show value mappings'), (new CUrl('zabbix.php'))
-			->setArgument('action', 'valuemap.list')
-			->getUrl()
-		))->setAttribute('target', '_blank')
-	];
+if ($data['host']['flags'] != ZBX_FLAG_DISCOVERY_CREATED) {
+	$form_list->addRow(new CLabel(_('Value mapping'), 'valuemapid_ms'),
+		(new CMultiSelect([
+			'name' => 'valuemapid',
+			'object_name' => 'valuemaps',
+			'disabled' => $readonly,
+			'multiple' => false,
+			'data' => $data['valuemap'],
+			'popup' => [
+				'parameters' => [
+					'srctbl' => 'valuemaps',
+					'srcfld1' => 'valuemapid',
+					'dstfrm' => $form->getName(),
+					'dstfld1' => 'valuemapid',
+					'hostids' => [$data['hostid']],
+					'context' => $data['context'],
+					'editable' => true
+				]
+			]
+		]))
+			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
+		'row_valuemap'
+	);
 }
 
 $form_list
-	->addRow(new CLabel(_('Show value'), 'label-valuemap'), $valuemap_select, 'row_valuemap')
 	->addRow(
 		new CLabel(_('Enable trapping'), 'allow_traps'),
 		[
@@ -862,37 +853,6 @@ $form_list
 		'row_trapper_hosts'
 	);
 
-// Add "New application" and list of applications to form list.
-if ($discovered_item) {
-	$form->addVar('new_application', '');
-	foreach ($data['db_applications'] as $db_application) {
-		foreach ($data['applications'] as $application) {
-			if ($db_application['applicationid'] == $application) {
-				$form->addVar('applications[]', $db_application['applicationid']);
-			}
-		}
-	}
-
-	$application_list_box = new CListBox('applications_names[]', $data['applications'], 6);
-	foreach ($data['db_applications'] as $application) {
-		$application_list_box->addItem($application['applicationid'], CHtml::encode($application['name']));
-	}
-	$application_list_box->setEnabled(!$discovered_item);
-}
-else {
-	$form_list->addRow(new CLabel(_('New application'), 'new_application'), (new CSpan(
-		(new CTextBox('new_application', $data['new_application']))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-	))->addClass(ZBX_STYLE_FORM_NEW_GROUP));
-
-	$application_list_box = new CListBox('applications[]', $data['applications'], 6);
-	$application_list_box->addItem(0, '-'._('None').'-');
-	foreach ($data['db_applications'] as $application) {
-		$application_list_box->addItem($application['applicationid'], CHtml::encode($application['name']));
-	}
-}
-
-$form_list->addRow(_('Applications'), $application_list_box);
-
 // Append populate host to form list.
 if ($discovered_item) {
 	$form->addVar('inventory_link', 0);
@@ -941,6 +901,15 @@ $form_list
 // Append tabs to form.
 $itemTab = (new CTabView())
 	->addTab('itemTab', $data['caption'], $form_list)
+	->addTab('tags-tab', _('Tags'),
+		new CPartial('configuration.tags.tab', [
+			'source' => 'item',
+			'tags' => $data['tags'],
+			'show_inherited_tags' => $data['show_inherited_tags'],
+			'readonly' => $discovered_item
+		]),
+		TAB_INDICATOR_TAGS
+	)
 	->addTab('preprocTab', _('Preprocessing'),
 		(new CFormList('item_preproc_list'))
 			->addRow(_('Preprocessing steps'),
@@ -977,16 +946,16 @@ if ($data['itemid'] != 0) {
 			);
 	}
 
-	$buttons[] = (new CButtonDelete(_('Delete item?'), url_params(['form', 'itemid', 'hostid'])))
+	$buttons[] = (new CButtonDelete(_('Delete item?'), url_params(['form', 'itemid', 'hostid', 'context']), 'context'))
 		->setEnabled(!$data['limited']);
-	$buttons[] = new CButtonCancel(url_param('hostid'));
+	$buttons[] = new CButtonCancel(url_params(['hostid', 'context']));
 
 	$itemTab->setFooter(makeFormFooter(new CSubmit('update', _('Update')), $buttons));
 }
 else {
 	$itemTab->setFooter(makeFormFooter(
 		new CSubmit('add', _('Add')),
-		[(new CSimpleButton(_('Test')))->setId('test_item'), new CButtonCancel(url_param('hostid'))]
+		[(new CSimpleButton(_('Test')))->setId('test_item'), new CButtonCancel(url_params(['hostid', 'context']))]
 	));
 }
 
